import React, { useCallback, useState } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button, Popconfirm, Image, Space, notification } from 'antd';
import request, { queryTable } from '@/utils/request';

const StudentList = () => {
  const [, setLoading] = useState(false);
  const handleStudentClick = useCallback((id) => {
    history.push(id ? `/student/student/edit?id=${id}` : '/student/student/edit');
  }, []);

  const actions = [
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => handleBannerClick()}>
      新建
    </Button>,
  ];


  const columns = [
    {
      title: '编号',
      dataIndex: 'person_id',
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '姓名',
      dataIndex: 'name',
      align: 'center',
    },
    {
      title: '昵称',
      dataIndex: 'nickName',
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '联系方式',
      dataIndex: 'phone',

      align: 'center',
    },
    {
      title: '学校',
      dataIndex: 'schoolName',

      align: 'center',
    },
    {
      title: '专业',
      dataIndex: 'specialtyName',

      align: 'center',
    },

    {
      title: '学号',
      dataIndex: 'status',
      align: 'center',
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a onClick={() => handleStudentClick(record.serialNo)}>用户详情 </a>
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        request={queryTable('/person')}
        rowKey="schoolId"
        headerTitle="学校列表"
        search={{
          labelWidth: '4em',
        }} 
       
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(StudentList);
